==> AdvancedContent-v.0.5.tgz: AdvancedContent/lang/ext/nl_NL.php <==
<?php
$lang['AdvancedContent'] = 'Advanced Content ';
$lang['installed'] = 'Module AdvancedContent %s is ge&iuml;nstalleerd';
$lang['uninstalled'] = 'Module AdvancedContent %s is gede&iuml;nstalleerd';
$lang['upgraded'] = 'Module AdvancedContent is bijgewerkt naar %s';
$lang['postinstall'] = 'Module AdvancedContent %s is ge&iuml;nstalleerd';
$lang['postuninstall'] = 'Module AdvancedContent %s is gede&iuml;nstalleerd';
$lang['confirmuninstall'] = 'Weet u zeker dat u de module AdvancedContent wilt de&iuml;nstalleren?';
$lang['error_duplicatecontent'] = '<em><strong>Notice:</strong> {content block=&#039;%s&#039; ... } is ambigous. Block names must be unique. <br />This block is disabled. Only first block will be shown. Check your page template and chose a different value of param &#039;block&#039;.</em>';
$lang['notice_duplicatecontent'] = '<em><strong>Let op:</strong> Dit blok komt meerdere keren voor in het sjabloon. Alleen het eerste blok wordt hier getoond.</em>';
$lang['error_basicattrib'] = '<em><strong>Notice:</strong> Cannot use basic content property name &#039;%s&#039; as value of param &#039;block&#039;. <br />This block is disabled. Check your page template and chose a different value of param &#039;block&#039;.</em>';
$lang['error_expiredate'] = 'Einddatum moet na de startdatum vallen';
$lang['youareintext'] = 'Huidige directory';
$lang['dimensions'] = 'Afbeelding Afmetingen';
$lang['size'] = 'Bestandsgrootte';
$lang['inherit_from_parent'] = 'Neem over van de ouder';
$lang['none'] = 'geen';
$lang['invalid'] = 'fout';
$lang['invalid_blocktype'] = '<em><strong>Notice:</strong> Invalid value &#039;%s&#039; of param block_type in block &#039;%s&#039;.<br />Check your page template.</em>';
$lang['yes'] = 'Ja';
$lang['no'] = 'Nee';
$lang['frontendaccess'] = 'Frontend Toegang';
$lang['redirectpage'] = 'Redirect Page if no access';
$lang['showloginform'] = 'Toon login formulier';
$lang['registeredusers'] = 'Alleen geregistreerde gebruikers';
$lang['block'] = 'Block ';
$lang['useexpiredate'] = 'Gebruik verloopdatum';
$lang['startdate'] = 'Start Datum';
$lang['enddate'] = 'Eind Datum';
$lang['blockcontent'] = 'Block Inhoud';
$lang['setpageinactive'] = 'Pagina Inactief';
$lang['deletepage'] = 'Verwijder Pagina';
$lang['uninstallaction'] = 'De&iuml;nstalleer bewerking';
$lang['setcontent1'] = 'Stel alle pagina&#039;s in met het type Content';
$lang['setcontent2'] = 'Stel alle pagina&#039;s in met het type Content en verwijder alle extra content blocks';
$lang['prefsupdated'] = 'Voorkeuren bijgewerkt';
$lang['fileoperations'] = 'Bestandsbewerkingen';
$lang['uploadnewfile'] = 'Upload een nieuw bestand';
$lang['createnewdir'] = 'Maak een nieuwe directory';
$lang['uploadfile'] = 'Upload ';
$lang['createdir'] = 'Maak';
$lang['success'] = 'Ok&eacute;';
$lang['error'] = 'Fout';
$lang['fileuploaded'] = 'Bestand ge&uuml;ploaded';
$lang['nodirname'] = 'Geen directory naam ingevoerd';
$lang['direxists'] = 'Directory naam bestaat al';
$lang['newdircreated'] = 'Nieuwe directory aangemaakt';
$lang['newdirfailed'] = 'Er is een fout opgetreden tijdens het aanmaken van een directory';
$lang['nofile'] = 'Er is geen bestand ge&uuml;pload';
$lang['filetoobig'] = 'Het bestand is te groot';
$lang['containsillegalchars'] = 'Filename contains one or more illegal characters (&#039;,&quot;,+,*,\,/,&amp;,$)';
$lang['uploadfailed'] = 'Er is een fout opgetreden bij het plaatsen van het ge&uuml;ploade bestand';
$lang['confirmdelete'] = 'Weet u zeker dat u dit bestand wilt verwijderen %s?';
$lang['deletefilesuccess'] = 'is verwijderd';
$lang['deletefilefailed'] = 'kan niet worden verwijderd';
$lang['deletesubdirfailed'] = 'kan niet worden verwijderd';
$lang['deletesubdirsuccess'] = 'is verwijderd';
$lang['confirmdeletedir'] = 'Weet u zeker dat u de directory %s wilt verwijderen?';
$lang['deletedir'] = 'Verwijder lege subdirectory';
$lang['deletefile'] = 'Bestand verwijderen';
$lang['restrictdirs'] = 'Restrict user&#039;s dir access';
$lang['showfilemanagement'] = 'Toon Bestandsbeheer Opties';
$lang['showthumbnailfiles'] = 'Toon miniaturen';
$lang['allowscaling'] = 'Allow on-the-fly resizing of uploaded images';
$lang['scalingwidth'] = 'Scaling width';
$lang['scalingheight'] = 'Scaling height';
$lang['defaultdimensions'] = 'Default dimensions';
$lang['auto'] = 'Automatisch';
$lang['relativeurls'] = 'Relatieve urls';
$lang['filepickerstyle'] = 'Filepicker stijl';
$lang['filepickersize'] = 'Filepicker afmeting';
$lang['filenameonly'] = 'Toon bestandsnamen';
$lang['thumbnailsonly'] = 'Toon miniaturen';
$lang['showthumbnailfilestext'] = 'Toon miniaturen als gewoon bestand';
$lang['filenameandthumbnails'] = 'Toon miniatuur en bestandsnaam';
$lang['makethumbnail'] = 'Maak miniaturen';
$lang['filepickersettings'] = 'FilePicker instellingen';
$lang['resizeto'] = 'Verschaal afbeelding naar';
$lang['keepaspectratio'] = 'Behoudt verhouding';
$lang['allowupscaling'] = 'Sta vergroten toe';
$lang['decimaldelimiter'] = '.';
$lang['thousanddelimiter'] = ',';
$lang['dirnotfound'] = 'Directory &#039;%s&#039; niet gevonden!';
$lang['selectimage'] = 'Browse afbeeldingen';
$lang['selectfile'] = 'Browse bestanden';
$lang['deletepages'] = 'Verwijder alle pagina&#039;s met het type AdvancedContent';
$lang['usemimetype'] = 'Use mime-type to get file type';
$lang['importpages'] = 'Set all Pages of type content to type AdvancedContent.';
$lang['pagesimported'] = 'Alle Content pagina&#039;s ingesteld als AdvancedContent.';
$lang['confirmimport'] = 'Do you really want to change the content type of all content pages?';
$lang['nomimetype'] = 'No mime-type function available or not configured properly. This feature is disabled.';
$lang['toggle_message'] = 'Verberg dit bericht';
$lang['contentsettings'] = 'Standaard AdvancedContent Instellingen';
$lang['redirectparams'] = 'URL params to append when redirecting (param1=value1 param2=value2 ...)';
$lang['evaluatesmarty'] = 'Use smarty to create the params';
$lang['noimagefile'] = '%s is geen afbeeldingsbestand';
$lang['filetypenotallowed'] = 'Bestandstype %s is niet toegestaan';
$lang['utma'] = '156861353.1738896039.1278840000.1282320304.1282376435.225';
$lang['utmz'] = '156861353.1282296708.219.49.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php/board,13.0.html';
$lang['qca'] = 'P0-854387043-1278840000917';
$lang['utmb'] = '156861353.2.10.1282376435';
$lang['utmc'] = '156861353';
?>

==> AdvancedContent-v.0.6.tgz: AdvancedContent/lang/ext/nl_NL.php <==
<?php
$lang['AdvancedContent'] = 'Advanced Content ';
$lang['installed'] = 'Module AdvancedContent %s is ge&iuml;nstalleerd';
$lang['uninstalled'] = 'Module AdvancedContent %s is gede&iuml;nstalleerd';
$lang['upgraded'] = 'Module AdvancedContent is bijgewerkt naar %s';
$lang['postinstall'] = 'Module AdvancedContent %s is ge&iuml;nstalleerd';
$lang['postuninstall'] = 'Module AdvancedContent %s is gede&iuml;nstalleerd';
$lang['confirmuninstall'] = 'Weet u zeker dat u de module AdvancedContent wilt de&iuml;nstalleren?';
$lang['error_duplicatecontent'] = '<em><strong>Notice:</strong> {content block=&#039;%s&#039; ... } is ambigous. Block names must be unique. <br />This block is disabled. Only first block will be shown. Check your page template and chose a different value of param &#039;block&#039;.</em>';
$lang['notice_duplicatecontent'] = '<em><strong>Let op:</strong> Dit blok komt meerdere keren voor in het sjabloon. Alleen het eerste blok wordt hier getoond.</em>';
$lang['error_basicattrib'] = '<em><strong>Notice:</strong> Cannot use basic content property name &#039;%s&#039; as value of param &#039;block&#039;. <br />This block is disabled. Check your page template and chose a different value of param &#039;block&#039;.</em>';
$lang['error_expiredate'] = 'Einddatum moet na de startdatum vallen';
$lang['youareintext'] = 'Huidige directory';
$lang['dimensions'] = 'Afbeelding Afmetingen';
$lang['size'] = 'Bestandsgrootte';
$lang['inherit_from_parent'] = 'Neem over van de ouder';
$lang['none'] = 'geen';
$lang['invalid'] = 'fout';
$lang['invalid_blocktype'] = '<em><strong>Notice:</strong> Invalid value &#039;%s&#039; of param block_type in block &#039;%s&#039;.<br />Check your page template.</em>';
$lang['yes'] = 'Ja';
$lang['no'] = 'Nee';
$lang['frontendaccess'] = 'Frontend Toegang';
$lang['redirectpage'] = 'Redirect Page if no access';
$lang['showloginform'] = 'Toon login formulier';
$lang['registeredusers'] = 'Alleen geregistreerde gebruikers';
$lang['block'] = 'Block ';
$lang['useexpiredate'] = 'Gebruik verloopdatum';
$lang['startdate'] = 'Start Datum';
$lang['enddate'] = 'Eind Datum';
$lang['blockcontent'] = 'Block Inhoud';
$lang['setpageinactive'] = 'Pagina Inactief';
$lang['deletepage'] = 'Verwijder Pagina';
$lang['uninstallaction'] = 'De&iuml;nstalleer bewerking';
$lang['setcontent1'] = 'Stel alle pagina&#039;s in met het type Content';
$lang['setcontent2'] = 'Stel alle pagina&#039;s in met het type Content en verwijder alle extra content blocks';
$lang['prefsupdated'] = 'Voorkeuren bijgewerkt';
$lang['fileoperations'] = 'Bestandsbewerkingen';
$lang['uploadnewfile'] = 'Upload een nieuw bestand';
$lang['createnewdir'] = 'Maak een nieuwe directory';
$lang['uploadfile'] = 'Upload ';
$lang['createdir'] = 'Maak';
$lang['success'] = 'Ok&eacute;';
$lang['error'] = 'Fout';
$lang['fileuploaded'] = 'Bestand ge&uuml;ploaded';
$lang['nodirname'] = 'Geen directory naam ingevoerd';
$lang['direxists'] = 'Directory naam bestaat al';
$lang['newdircreated'] = 'Nieuwe directory aangemaakt';
$lang['newdirfailed'] = 'Er is een fout opgetreden tijdens het aanmaken van een directory';
$lang['nofile'] = 'Er is geen bestand ge&uuml;pload';
$lang['filetoobig'] = 'Het bestand is te groot';
$lang['containsillegalchars'] = 'Filename contains one or more illegal characters (&#039;,&quot;,+,*,\,/,&amp;,$)';
$lang['uploadfailed'] = 'Er is een fout opgetreden bij het plaatsen van het ge&uuml;ploade bestand';
$lang['confirmdelete'] = 'Weet u zeker dat u dit bestand wilt verwijderen %s?';
$lang['deletefilesuccess'] = 'is verwijderd';
$lang['deletefilefailed'] = 'kan niet worden verwijderd';
$lang['deletesubdirfailed'] = 'kan niet worden verwijderd';
$lang['deletesubdirsuccess'] = 'is verwijderd';
$lang['confirmdeletedir'] = 'Weet u zeker dat u de directory %s wilt verwijderen?';
$lang['deletedir'] = 'Verwijder lege subdirectory';
$lang['deletefile'] = 'Bestand verwijderen';
$lang['restrictdirs'] = 'Restrict user&#039;s dir access';
$lang['showfilemanagement'] = 'Toon Bestandsbeheer Opties';
$lang['showthumbnailfiles'] = 'Toon miniaturen';
$lang['allowscaling'] = 'Sta het on-the-fly verschalen van afbeeldingen toe';
$lang['scalingwidth'] = 'Verschaling breedte';
$lang['scalingheight'] = 'Verschaling hoogte';
$lang['defaultdimensions'] = 'Standaard waarden';
$lang['auto'] = 'Automatisch';
$lang['relativeurls'] = 'Relatieve urls';
$lang['filepickerstyle'] = 'Filepicker stijl';
$lang['filepickersize'] = 'Filepicker afmeting';
$lang['filenameonly'] = 'Toon bestandsnamen';
$lang['thumbnailsonly'] = 'Toon miniaturen';
$lang['showthumbnailfilestext'] = 'Toon miniaturen als gewoon bestand';
$lang['filenameandthumbnails'] = 'Toon miniatuur en bestandsnaam';
$lang['makethumbnail'] = 'Maak miniaturen';
$lang['filepickersettings'] = 'FilePicker instellingen';
$lang['resizeto'] = 'Verschaal afbeelding naar';
$lang['keepaspectratio'] = 'Behoudt verhouding';
$lang['allowupscaling'] = 'Sta vergroten toe';
$lang['decimaldelimiter'] = '. ';
$lang['thousanddelimiter'] = ', ';
$lang['dirnotfound'] = 'Directory &#039;%s&#039; niet gevonden!';
$lang['selectimage'] = 'Browse afbeeldingen';
$lang['selectfile'] = 'Browse bestanden';
$lang['deletepages'] = 'Verwijder alle pagina&#039;s met het type AdvancedContent';
$lang['usemimetype'] = 'Use mime-type to get file type';
$lang['importpages'] = 'Stel alle pagina&#039;s in met het type AdvancedContent.';
$lang['pagesimported'] = 'Alle Content pagina&#039;s ingesteld als AdvancedContent.';
$lang['confirmimport'] = 'Do you really want to change the content type of all content pages?';
$lang['nomimetype'] = 'No mime-type function available or not configured properly. This feature is disabled.';
$lang['toggle_message'] = 'Verberg dit bericht';
$lang['contentsettings'] = 'Standaard AdvancedContent Instellingen';
$lang['redirectparams'] = 'URL params to append when redirecting (param1=value1 param2=value2 ...)';
$lang['evaluatesmarty'] = 'Use smarty to create the params';
$lang['noimagefile'] = '%s is geen afbeeldingsbestand';
$lang['filetypenotallowed'] = 'Bestandstype %s is niet toegestaan';
$lang['utma'] = '156861353.1335698708.1284586217.1285407291.1285425870.60';
$lang['utmz'] = '156861353.1285000824.40.9.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php/topic,47502.0/topicseen.html';
$lang['qca'] = 'P0-1551306179-1284586216711';
$lang['utmb'] = '156861353.1.10.1285425870';
$lang['utmc'] = '156861353';
?>
